@@ -1,7 +1,7 @@
 #! /bin/sh
 
 top=`pwd`
-gcc_version=4.8.2
+gcc_version=4.8.3
 contact="Andris Pavenis <andris.pavenis@iki.fi>";
 
 # Configuration params
@@ -36,9 +36,12 @@ archive=${1-gcc-$gcc_version.tar.bz2}
 #
 #  Detect required tar command line parameters for unpacking source archice
 #
-tar_param=xf`case $archive in *.gz|*.tgz) echo 'z';; *.bz2) echo 'j';; *.xz) echo 'J';; esac`
+tar_param=`case $archive in *.gz|*.tgz) echo '--use=gzip' ;;
+     *.bz2) echo '--use=bzip2' ;;
+     *.xz) echo '--use=xz' ;;
+esac`
 
-if test "$tar_param" = "xf" ; then
+if test "$tar_param" = "" ; then
     echo "Failed to detect how to decompress $archive"
     exit 1
 fi
@@ -47,7 +50,7 @@ rm -rf gnu
 mkdir gnu
 
 rm -f $top/s-sources
-( cd gnu && tar $tar_param $top/$archive && echo $archive >$top/s-sources )
+( cd gnu && tar xf $top/$archive $tar_param && echo $archive >$top/s-sources )
 
 if ! [ -f s-sources ] ; then
     echo "Cannot unpack GCC sources"
@@ -342,7 +345,8 @@ if $create_gccnnns_zip; then
             -and -not -name '.cvsignore' \
             -and -not -name '*~*' \
             -and -not -name '*.orig' \
-            -and -not -name '.brik' ;
+            -and -not -name '.brik' \
+            -and -not -name 'zh_*.po'; \
         find manifest -type f;
     ) | grep -v 'autom4te\.cache' | sort >$top/manifest/${arcprefix}s.mft
 
